<img src="https://raw.githubusercontent.com/databio/refgenie/master/docs/img/refgenie_logo.svg?sanitize=true" alt="Refgenie" height="70"/><br>

A standardized reference genome resource manager. See the [documentation](http://refgenie.databio.org).
